@@ -5,11 +5,13 @@ from os import environ
 from pathlib import PurePath, PurePosixPath
 from typing import Callable, Dict, List, Optional, Union
 
-from ..os import OS
-from ..utils import _Ensure, _EnsureCallable
+from ...core.os.path_converter import PathConverter
+from ...core.utils import _Ensure, _EnsureCallable
 
 
 class Process(ABC):
+    active: List[Process] = []
+
     @staticmethod
     def create(
         executable: Union[str, PurePath],
@@ -18,7 +20,8 @@ class Process(ABC):
         writer: Optional[Callable[[str], None]] = None,
         inherit_environment: bool = True,
     ) -> Process:
-        from .subprocess import _SubProcess
+        # Avoid circular import
+        from .subprocess import _SubProcess  # pylint: disable=import-outside-toplevel,cyclic-import
 
         return _SubProcess(executable, arguments, environment, writer, inherit_environment)
 
@@ -38,9 +41,10 @@ class Process(ABC):
         _Ensure.type(inherit_environment, bool, "inherit_environment")
         self.output: Optional[str] = None
         self.exit_code: int = -1
-        self._executable: PurePath = OS.posix_to_machine_path(
+
+        self._executable: PurePath = PathConverter.from_path(
             executable if isinstance(executable, PurePath) else PurePosixPath(executable)
-        )
+        ).to_machine()
         environment = {} if environment is None else environment
         if inherit_environment:
             current_env = environ.copy()
@@ -82,6 +86,17 @@ class Process(ABC):
     def kill(self):
         raise NotImplementedError("This method must be implemented")
 
+    @property
+    @abstractmethod
+    def is_running(self) -> bool:
+        raise NotImplementedError("This method must be implemented")
+
+    def _process_started(self):
+        Process.active.append(self)
+
+    def _process_stopped(self):
+        Process.active.remove(self)
+
     class ChildProcessStopped(ChildProcessError):
         ...
 
