@@ -1,7 +1,7 @@
 from .....core.utils import _Enum
+from .....model.argument.option.common._decoder import _DecodedOption
+from .....model.argument.option.long import LongOptionWithValue
 from .....model.platform.platform import Platform
-from ..long import LongOptionWithValue
-from ._decoder import _DecodedOption
 
 __all__ = ["PlatformOption"]
 
@@ -11,5 +11,5 @@ class PlatformOption(LongOptionWithValue, _DecodedOption[Platform]):
         LongOptionWithValue.__init__(self, "platform", description)
         _DecodedOption.__init__(self, description)
 
-    def _convert(self, input: str) -> Platform:
-        return _Enum.parse_value(Platform, input)
+    def _convert(self, value: str) -> Platform:
+        return _Enum.parse_value(Platform, value)
